%  *********************************************************************
%  
%  getdata.m
%
%  Program for "Information-Constrained State-Dependent Pricing"
%      by Michael Woodford
%
%  Loads data needed for plots from file names saved by getfiles.m 
%
%  *********************************************************************

kappaLoc = zeros(noFiles,2); kappas = zeros(noFiles,1); 
thetaLoc = zeros(noFiles,2); thetas = zeros(noFiles,1);

Xlbars = zeros(noFiles,1);  % stores lambda_bar from each file
Xqs  = cell(1,noFiles);     % stores qval from each file 
XLqs = cell(1,noFiles);     % stores Lambda(qval) from each file 
Xfqs = cell(1,noFiles);     % stores f(qval) from each file
Xdqs = cell(1,noFiles);     % stores delta_p from each file 
Xfdqs= cell(1,noFiles);     % stores f(delta_p) from each file

len=21;                       % max duration in hazard plot
Xmons  = (0:1:len-1)';        % stores months for hazard plot 
Xdurs  = zeros(len,noFiles);  % stores hazard data from each file 

for r=1:noFiles
    
    file1 = fileNames{1,r};
    filepath=strcat(paths,fileNames{1,r});
    
    % Run basic checks on file names:
    if ~exist(filepath,'file')
        fprintf('\nError replicating figures: %s does not exist in %s. \n', file1,paths);
        errLog=1;
        return
    end
    
    if isempty(findstr1(file1, '_k')) || isempty(findstr1(file1, 'th')) 
        fprintf('\nWrong input file: %s.\nFile names must be of the form *_kXthY.mat where kappa=X/1000 and theta=Y/1000.\n',file1);
        errLog=1;
        return        
    end   
    
    kappaLoc(r,1)=findstr1(file1, '_k')+size('_k',2);
    thetaLoc(r,1)=findstr1(file1, 'th')+size('th',2);        
    kappaLoc(r,2)=thetaLoc(r,1)-3;
    thetaLoc(r,2)=findstr1(file1, '.')-1;
    
    if isempty(0+(str2double(file1(kappaLoc(r,1):kappaLoc(r,2))))) || isempty(0+(str2double(file1(thetaLoc(r,1):thetaLoc(r,2)))))
        fprintf('\nWrong input file: %s.\nFile names must be of the form *_kXthY.mat where kappa=X/1000 and theta=Y/1000.\n',file1);
        errLog=1;
        return 
    end      
    
    kappas(r)=str2double(file1(kappaLoc(r,1):kappaLoc(r,2)))./1000;  % kappa values from all files
    thetas(r)=str2double(file1(thetaLoc(r,1):thetaLoc(r,2)))./1000;  % theta values from all files
  
    % Load and store data needed for plots:
    load(filepath); 
    
    Xlbars(r,1)= lbar;
    Xqs{1,r}   = qval;   
    Xdqs{1,r}  = qch;    
    XLqs{1,r}  = L(qval,lbar,vc,qstar);  
    Xfqs{1,r}  = fqval;  
    Xfdqs{1,r} = fch;    
    Xdurs(:,r) = ypoly(1:len);
    Xnus1 = nu(:,1);
    Xnus3 = nu(:,3); 
    XHnus1(:,r)= Hnu(:,1);
    XHnus3(:,r)= Hnu(:,3);
    Xcalvo(:,r)= calvo(:,1); 
    Xpix       = pi(qval); 
end

clearvars -except X* kappas thetas noFiles answer errLog

