%  *********************************************************************
%  
%  getfiles.m
%
%  Program for "Information-Constrained State-Dependent Pricing"
%      by Michael Woodford
%
%  Prompts user to select whether to replicate figures from paper or 
%  to make own plots. Saves names of files to be used for generating plots.  
%
%  NOTE: In order to be able to load the files, files must be of the form
%  *_kXthY.mat where kappa=X/1000 and theta=Y/1000
%
%  *********************************************************************


options={'Generate Figures 1 through 8 (I have all the files needed )',...
         'Allow me to select files for which to generate figures'};
     
[answer,ok] = listdlg('PromptString','Select option:',...
                'SelectionMode','single','ListSize',[500 100],...
                'ListString',options);
% Load data:  
if isempty(answer)             % user pressed cancel
    errLog=1;
    return

elseif answer==1               % generate plots from paper 
    
    paths = strcat(pwd,'/');   % look in current directory
    noFiles=6; 
    fileNames=cell(1,6); 
    fileNames{1,1}='savedpeq_k500th0.mat';  
    fileNames{1,2}='savedpeq_k500th50.mat'; 
    fileNames{1,3}='savedpeq_k500th500.mat'; 
    fileNames{1,4}='savedpeq_k500th5000.mat'; 
    fileNames{1,5}='savedpeq_k500th50000.mat'; 
    fileNames{1,6}='savedpeq_k500thInf.mat'; 
       
elseif answer==2               % select simulation files to use:
   
    [files,paths, findex] = ...
    uigetfile('*.mat','Select files of the form *_kXthY.mat where kappa=X/1000 and theta=Y/1000:','MultiSelect','on');

    if isequal(files,0) || isequal(paths,0)
       errLog=1;
       return                  % user pressed cancel
    end

    if ~iscell(files)          % single file selected
        noFiles=1; 
        fileNames=cell(1,1); 
        fileNames{1,1}=files; 
         
    else                       % multiple files selected
        fileNames=files; 
        noFiles = size(fileNames,2);
    end
end

if noFiles > 6                 % for colors, line settings in peqPlotAll 
    fprintf('\nToo many files selected: 6 is maximum.\n'); 
    errLog=1;
    return 
end

