%  *********************************************************************
%  
%  lambda.m
%
%  Program for "Information-Constrained State-Dependent Pricing"
%      by Michael Woodford
%
%  Compute the optimal hazard function, L(q), given Chebyschev coefficients 
%  for the value function V(q), the maximizing value q*, and the mean
%  frequency of price changes, lbar
%
%  *********************************************************************

function lq=lambda(qval,l,c,qmin,qmax,qstar,theta,kappa)

n=size(c,1);
[nq,cq] = size(qval); 
qspace=fundefn('cheb',n,qmin,qmax);
V = @(x) funeval(c,qspace,x);

Max = V(qstar).*ones(nq,cq);
K = kappa.*ones(nq,cq);
Val = zeros(nq,cq); 
for cols=1:cq
    Val(:,cols)= V(qval(:,cols));
end

if theta==0
    lq = double((Max-Val-K)>0); 
else
    if theta==inf
        exponent = zeros(size(Max));
    else
        exponent = (1/theta).*(Max-Val-K);
    end
    lq1 = (l/(1-l)).*exp(exponent);
    intermed = ones(size(exponent)) + lq1;
    invintermed = intermed.^(-1);
    lq = ones(size(exponent))-invintermed; 
end

return 
