%  *********************************************************************
%  
%  pefsimiter.m
%
%  Program for "Information-Constrained State-Dependent Pricing"
%      by Michael Woodford
%
%  Simulation approach for computing equilibrium lbar and f(q)
%
%  *********************************************************************
 
function [nsim,Jlambda,int1,int2,fqval] =...
    pefsimiter(lbar,qstar,qmin,qmax,qval,vc,V,L,at,ut,kappa,nbar,Nmax)   
     

nstar=0;   % counter for number of times simulation is restarted at q* (<=nbar)
nsim=1;    % counter for the total number of simuluated values of q (<=Nmax)
               
qsim=zeros(Nmax,1);   % pre-review normalized price
qsim(1) = qstar;      % start at optimal q*
qtild=qsim;           % post-review normalized price                 
Vstar=V(qstar,vc);

lqapprox = 0;         % counters for high theta approximation
lqapprox2= 0;
jlambda  = 0;         % cumulative hazard
 

while nstar<=nbar 
    nsim=nsim+1;
    
    % post-shock, pre-review normalized price 
    qsim(nsim)=qtild(nsim-1)+at(nsim);      
        qsim(nsim)=min(qmax,qsim(nsim));     % enforce grid limits 
        qsim(nsim)=max(qmin,qsim(nsim));
    
    % hazard of pre-review price        
    lsim=L(qsim(nsim),lbar,vc,qstar);
    jlambda=jlambda+lsim;       
    
    % high theta approximation
    term1=Vstar-V(qsim(nsim),vc)-kappa;
    term2=term1.^2;
    lqapprox=lqapprox+term1;    
    lqapprox2=lqapprox2+term2;

    
    if (ut(nsim) < lsim)        % update price
        qtild(nsim)=qstar;
        nstar=nstar+1;    
    else
        qtild(nsim)=qsim(nsim);
    end

    if nsim==Nmax,break,end  % have reached end of simulated series
end

% Normalized price realization:
qsim = qsim(1:nsim,1);

% Resulting lambda-bar:
Jlambda = jlambda/(nsim-1);     
int1 = lqapprox/(nsim-1); 
int2 = lqapprox2/(nsim-1); 

% Approximation to the distribution of pre-review prices, f(q):
fqval=histc(qsim,qval);
fqval=fqval./size(qsim,1);


return 

    