%  *********************************************************************
%  
%  pehazard.m
%
%  Program for "Information-Constrained State-Dependent Pricing"
%      by Michael Woodford
%
%  Compute hazard function and generate polynomial smoothing 
%  (Note, degree of success in smoothing results varies by simulation)
%
%  *********************************************************************


function [dpoly,ypoly,dur,haz]=pehazard(duration,deg)

dursort = sort(duration);           % vector of durations obtained from simulation  
nd  = size(dursort,1);
dur = [1 diff(dursort)']~=0;        % index of new observed duration
durcount = diff([find(dur) nd+1]);  % frequency with which observe each duration
durcount = durcount';
dur = dursort(dur);

top = sum(durcount)-cumsum(durcount);
bot = durcount+top;
haz = ones(size(top))-top./bot;     % hazard for price adjustment
dur = dur(1:size(dur,1)-1);         % time elapsed since last price change  
haz = haz(1:size(haz,1)-1);

% Smooth hazard, using polynomial of degree deg, specified by peqParam:  
len = min(size(dur,1),25);    % simulation gets noisy further out
if deg==1                     % shorten for high theta since even noisier 
   len = min(size(dur,1),22);
end

dpoly = dur(1:len,1); 
fitPoly = polyfit(dpoly, haz(1:len,1), deg); 
ypoly   = polyval(fitPoly, dpoly);

return 
