%  *********************************************************************
%  
%  peqPlot.m
%
%  Program for "Information-Constrained State-Dependent Pricing"
%      by Michael Woodford
%
%  Generate and save plots of interest for single calibration
%  Used as standalone (user prompted to specify file from which to generate
%  plots) or as part of peqMain (if peqMain is run as standalone, for a
%  single calibration). 
%
%  *********************************************************************

if isempty(who) % running peqPlot as standalone hence ask for input file
    
    % Add COMPECON toolbox:
    cepath='compecon/'; path([cepath 'CEtools'],path);
    path([cepath 'CEdemos'],path)

    [file1,path1, findex] = ...
        uigetfile('*.mat','Select single file of the form *_kXthY.mat where kappa=X/1000 and theta=Y/1000:','MultiSelect','off');
    
    if isequal(file1,0) || isequal(path1,0)
       clear
       return                  % user pressed cancel
    end
    
    if isempty(findstr1(file1, '_k')) || isempty(findstr1(file1, 'th')) 
        fprintf('\nWrong input file: %s.\nFile names must be of the form *_kXthY.mat where kappa=X/1000 and theta=Y/1000.\n',file1);
        clear
        return        
    end   
    
    kappaLoc(1,1)=findstr1(file1, '_k')+size('_k',2);
    thetaLoc(1,1)=findstr1(file1, 'th')+size('th',2);        
    kappaLoc(1,2)=thetaLoc(1,1)-3;
    thetaLoc(1,2)=findstr1(file1, '.')-1;
    
    if isempty(0+(str2double(file1(kappaLoc(1,1):kappaLoc(1,2))))) || isempty(0+(str2double(file1(thetaLoc(1,1):thetaLoc(1,2)))))
        fprintf('\nWrong input file: %s.\nFile names must be of the form *_kXthY.mat where kappa=X/1000 and theta=Y/1000.\n',file1);
        clear
        return 
    end     
    
    load(strcat(path1,file1));

    fprintf('Plotting results for %s with the following parameters: \n', file1);
    fprintf('\nkappa:    %5.3f\n',kappa)
    fprintf('theta:    %5.3f\n',theta)
    fprintf('sig(a):   %5.3f\n',siga)
end
 

fgA=figure; plot(q,pi(q))
    xlim([-0.2 0.2])
    xlabel('\itq') 

saveas(fgA,'fig_Pix','pdf')   
%saveas(fgA,'fig_Pix','eps')      

fgB=figure; plot(nu(:,1),Hnu(:,1),'b.-')
        hold on
        plot(nu(:,1),calvo(:,1),'r--','LineWidth',2)
        plot(nu(:,1),zeros(size(nu(:,1))),'r:')
        xlim([min(nu(:,1)) max(nu(:,1))]); 
        ylim([min(nu(:,1)) max(nu(:,1))]);
        xlabel('\it\nu');
        if theta==inf
        legend('\theta=\infty','Calvo','Location','SouthEast')
        else
        legend(strcat('\theta=',num2str(theta)),'Calvo','Location','SouthEast')
        end
        hold off
        
saveas(fgB,figout2,'pdf')   
%saveas(fgB,figout2,'eps')  

fgC=figure;
    subplot(3,2,1), plot(qval,V(qval,vc),'b-','LineWidth',2)
        title('Value function');
        xlabel('\itq');
        xlim([-0.4 0.4]); 
         
    subplot(3,2,2), plot(qval,L(qval,lbar,vc,qstar),'b-','LineWidth',2)
        title('Hazard function');
        xlabel('\itq');
        axis([qmin qmax 0 1])
        
    subplot(3,2,3), plot(qval,fqval,'b-','LineWidth',2)
        title('Invariant distribution');
        xlabel('\itq');
        axis([-0.6 0.6 0 0.1])
        
    subplot(3,2,4), plot(qch,fch,'b-','LineWidth',2)
        title('Distribution of price changes');
        xlabel('\it\Deltap');
        xlim([-0.6 0.6])
        
    subplot(3,2,5), plot(nu(:,1),Hnu(:,1),'b.-')
        hold on
        plot(nu(:,1),calvo(:,1),'r--','LineWidth',2)
        plot(nu(:,1),zeros(size(nu(:,1))),'r:')
        title('Mean price response');
        xlabel('\it\nu');
        hold off
        if theta==inf
        legend('\theta=\infty','Calvo','Location','SouthEast')
        else
        legend(strcat('\theta=',num2str(theta)),'Calvo','Location','SouthEast')
        end
        xlim([min(nu(:,1)) max(nu(:,1))]); 
        ylim([min(nu(:,1)) max(nu(:,1))]);
        
    subplot(3,2,6), plot(dpoly,ypoly,'b-','LineWidth',2)
        title('Price Duration');
        xlabel('months');
        set(gca,'XTick',[0 6 12 18])
        axis([0 20 0 0.35])

set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperPosition', [0.25 1.7 8 9]);

saveas(fgC,figout,'pdf')   
%saveas(fgC,figout,'eps')   

%fgD=figure; 
%    plot(qrplot,resid,'b-',qrplot,zeros(size(qrplot)),'g--')
%    if theta==inf
%       title('Value function residuals,\theta = \infty');
%    else        
%       title(['Value function residuals, \theta = ' num2str(theta)]);
%    end
%    xlim([qmin qmax]); xlabel('\itq');   
%saveas(fgD,'fig_VFresid','pdf')   
%saveas(fgD,'fig_VFresid','eps')   

