%  *********************************************************************
%  
%  peqPolicy.m
%
%  Program for "Information-Constrained State-Dependent Pricing"
%      by Michael Woodford
%
%  Find the stationary optimal policy {V(q), q*, Lambda(q), f(q)} given  
%  initial guesses for lambda-bar, V(q) and q*. 
%
%  *********************************************************************


% Using the history of idiosyncratic shocks, {a(t)}, and the history of
% signals, {u(t)}, simulate the path of normalized prices {q(t)} until 
% lbar=Integral[Lambda(q)f(q)dq] has converged

for it=1:maxlIter
     
    % Get V(q), q* (and hence L(q)) corresponding to conjectured lbar
    % Use Broyden's method, with vc, qstar as initial guesses  
    [vc,qstar]=pebroyden('pestateBr',vc,q,qmin,qmax,qstar,lbar,bzero,a,ha,cutoffs);  
          
    % Run simulation to obtain estimate of new lbar and new f(q) approximation: 
    fqvalprev=fqval;    
    [nqs,Jlambda,int1,int2,fqval] = pefsimiter(lbar,qstar,qmin,qmax,qval,vc,V,L,at,ut,kappa,nbar(it),Nsmax); 
    
    % Check convergence of lbar and update guess if necessary:          
    if theta >= cutoffs(2,1)    % high or infinite theta     
        condition = int1+(1/2)*(1/theta)*(1-2*lbar)*int2; 
        if abs(condition)<tol,break,end;
        if condition>0
           low = lbar;
        elseif condition<0
           high = lbar; 
        end
        
    elseif theta==cutoffs(1,1)  % theta=0: lbar=Jlambda
        lbar=Jlambda;
        fqresid = max(max(abs(fqval-fqvalprev)));
        break;
        
    else                        % low theta   
        diff = Jlambda-lbar;
        if abs(diff)<tol,break,end;
        if diff>0
            low = lbar;
        elseif diff<0
            high = lbar; 
        end
    end
    lbar=guess(low,high);
    
    % Store residual for f(q):
    fqresid = max(max(abs(fqval-fqvalprev)));
    
    
end 

clear Jlambda int1 int2 diff condition low high 
       
