%  *********************************************************************
%  
%  peqStat.m
%
%  Program for "Information-Constrained State-Dependent Pricing"
%      by Michael Woodford
%
%  Rerun simulation to compute statistics, including distribution
%  of price changes, response to monetary shock, expenditure on
%  information, and duration of prices
%
%  *********************************************************************

% Ss bounds:
rn1 = [qmin qstar]; rn2 = [qstar qmax];
Vdiff = @(x) V(qstar,vc).*ones(size(x))-V(x,vc)-kappa.*ones(size(x));
options=optimset('Display','off');
qlo=fzero1(Vdiff,rn1,options);
qhi=fzero1(Vdiff,rn2,options);

if qlo<qmin,qlo=qmin-eps;end
if qhi<qstar,qhi=qmax+eps;end
    
% Simulation for additional statistics:
[Hnu,ahat,bhat,fqval,fqtil,fch,duration,Info,Istar] = ...
     pefsim(nqs,nbar(it),lbar,qstar,qmin,qmax,qval,qtval,qch,vc,L,at,ut,theta,gz,qlo,qhi,nu,cutoffs); 
       
calvo  = lbar.*nu;  % to compare Calvo to ICSDP mean price response to nominal shock nu

% Price duration (raw and smoothed):
[dpoly,ypoly,draw, yraw]=pehazard(duration,deg);

% Value function residuals: 
peresid

% Mean, variance, standard deviation of q:
qbar=fqval'*qval; 
devs=qval-qbar*ones(size(qval)); devs=devs.^2;
qvar=devs'*fqval;
qsigma = qvar^(1/2);

% Mean, standard deviation, kurtosis of dq, share of small price changes:
meanch=fch'*qch;
mabsch=fch'*(abs(qch));
demean=qch-meanch;
devch=demean.^2;
stdch=(devch'*fch)^(1/2);
mom4=fch'*(demean.^4);
kurt=mom4/(stdch.^4);
percsmall=sum(fch(abs(qch)<0.05),1)/sum(fch,1);

% Information expenditures:
sk=kappa*lbar;
sth=theta*Info;
rth=Info/Istar;

% Clear simulation data and other:
clear at ut devs demean devch mom4 options

% Print output: 
fprintf('\nAverage frequency of price changes:         %5.3f\n',lbar)
fprintf('Average absolute size of price changes:     %5.3f\n',mabsch)
fprintf('Standard deviation of price changes:        %5.3f\n',stdch)
fprintf('Share of price changes less than 0.05:      %5.3f\n',percsmall)
fprintf('Kurtosis of price changes:                  %5.1f\n',kurt)

fprintf('\nq*:          %5.4f\n',qstar)
fprintf('s_kappa:     %5.4f\n',sk)
fprintf('s_theta:     %5.4f\n',sth)
fprintf('r_theta:     %5.4f\n',rth)
fprintf('beta:        %5.4f\n\n',bhat)

