%  *********************************************************************
%  
%  peresid.m
%
%  Program for "Information-Constrained State-Dependent Pricing"
%      by Michael Woodford
%
%  Evaluate value function residual as test of approximation
%
%  *********************************************************************

nplot=501;
qrplot=nodeunif(nplot,qmin,qmax); 

a1 = kron(ones(size(a)),qrplot);
a2 = kron(a,ones(size(qrplot)));
qrplotnew = a1+a2;    % q(next)
qrplotnew((qrplotnew<qmin),1)=qmin;
qrplotnew((qrplotnew>qmax),1)=qmax;

E0 = V(qstar,vc)-kappa;
Vfn= V(qrplotnew,vc);
EE = ones(size(Vfn)); 

if theta==cutoffs(1,1)                          % theta = 0
    E = max(E0.*EE,Vfn);
    
elseif theta==cutoffs(3,1)                      % theta = infinity   
    E = (1-lbar).*Vfn+lbar.*E0.*EE;

elseif theta>cutoffs(1,1) && theta<cutoffs(2,1) % low theta
    E1 = theta.*log(exp((1/theta).*(Vfn-E0.*EE))...
         +lbar/(1-lbar).*ones(size(Vfn)))...
         -theta.*log(exp(kappa/theta)+(lbar/(1-lbar))).*EE;

    E = (E0+kappa).*ones(size(E1))+E1;     
       
elseif theta>=cutoffs(2,1) && theta<cutoffs(3,1) % high theta    
    E = (1-lbar).*Vfn+lbar.*E0.*EE+...
        (1/2).*(1/theta).*lbar.*(1-lbar).*((E0.*EE-Vfn).^2); 
    
end

Emat = reshape(E,nplot,na);
Sum = Emat*ha;
Vqrplot = pi(qrplot)+beta.*Sum;

resid  = Vqrplot-funeval(vc,qspace,qrplot);
cresid = max(max(abs(resid)));

clear a1 a2 E0 E1 EE E Emat Sum nplot qrplotnew Vqrplot Vfn

